courses.Line (Activity line) — amici1

# `courses.Line` (Activity line)

Line(id, ref, name, company, contact_person, contact_role, excerpt_title, course_area, topic, description, every_unit, every, event_type, guest_role, body_template, description_de, description_fr, name_de, name_fr, excerpt_title_de, excerpt_title_fr)

Master tables : courses.Lines (Activity lines)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Reference (ref) : The reference. This must be either empty or unique.

- Designation (name) : The designation of this activity line as seen by the user e.g. when selecting the line.

- Organization (company) : Pointer to Company.

- represented by (contact_person) : Pointer to Person.

- represented as (contact_role) : The optional Role of the contact_person within company.

- Excerpt title (excerpt_title) : The text to print as title in enrolments.

- Layout (course_area) : Pointer to ActivityLayouts. This is used only when an application defines several variants of EnrolmentsByPupil.

- Topic (topic) : See `<django.db.models.fields.related.ForeignKey: topic>`.

- Description (description) : See `<lino.utils.mldbc.fields.BabelTextField: description>`.

- Recurrency (every_unit) : See `<lino.core.choicelists.ChoiceListField: every_unit>`.

- Repeat every (every) : See `<django.db.models.fields.IntegerField: every>`.

- Calendar entry type (event_type) : The type of calendar entries to be generated. If this is empty, no calendar entries will be generated.

- Manage presences as (guest_role) : The default guest role for particpants of calendar entries for activities in this series. Leave empty if you don’t want any presences management.

- Body template (body_template) : The body template to use when printing an activity of this line. Leave empty to use the site’s default (defined by body_template on the lino_xl.lib.excerpts.models.ExcerptType for Course)

- Description (de) (description_de) : See `<lino.core.fields.RichTextField: description_de>`.

- Description (fr) (description_fr) : See `<lino.core.fields.RichTextField: description_fr>`.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Excerpt title (de) (excerpt_title_de) : See `<django.db.models.fields.CharField: excerpt_title_de>`.

- Excerpt title (fr) (excerpt_title_fr) : See `<django.db.models.fields.CharField: excerpt_title_fr>`.

- Name (name_column) : See `lino_xl.lib.courses.models.Line.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.courses.models.Line.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.courses.models.Line.overview`.

Referenced from courses.Course.line

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
ref | Reference | The reference. This must be either empty or unique.
name | Designation | The designation of this activity line as seen by the user e.g. when selecting the line.
company | Organization | Pointer to Company.
contact_person | represented by | Pointer to Person.
contact_role | represented as | The optional Role of the contact_person within company.
excerpt_title | Excerpt title | The text to print as title in enrolments.
course_area | Layout | Pointer to ActivityLayouts. This is used only when an application defines several variants of EnrolmentsByPupil.
topic | Topic |
description | Description |
every_unit | Recurrency |
every | Repeat every |
event_type | Calendar entry type | The type of calendar entries to be generated. If this is empty, no calendar entries will be generated.
guest_role | Manage presences as | The default guest role for particpants of calendar entries for activities in this series. Leave empty if you don’t want any presences management.
body_template | Body template | The body template to use when printing an activity of this line. Leave empty to use the site’s default (defined by body_template on the lino_xl.lib.excerpts.models.ExcerptType for Course)
description_de | Description (de) |
description_fr | Description (fr) |
name_de | Designation (de) |
name_fr | Designation (fr) |
excerpt_title_de | Excerpt title (de) |
excerpt_title_fr | Excerpt title (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |